@@ -15,6 +15,7 @@ mice.1chain <- function(data, burnin = 10 , iter = 20 , Nimp = 10 ,
 		seed = NA, imputationMethod = NULL,
 		defaultImputationMethod = NULL, data.init = NULL, ...){
     ###################################################################------
+	CALL <- match.call()
     # burnin phase
     iterstep0 <- round( seq( burnin , iter , length = Nimp+1 ) )
     iterstep <- diff( iterstep0  )
@@ -101,6 +102,7 @@ mice.1chain <- function(data, burnin = 10 , iter = 20 , Nimp = 10 ,
 	midsobj$method <- imm$method
 #	midsobj$m <- Nimp
 	
+	midsobj$call <- CALL
 	
 	res <- list( "midsobj"=midsobj , "datlist"=datlist , "datalong" = datalong , 
 					"implist" = implist ,
@@ -110,6 +112,8 @@ mice.1chain <- function(data, burnin = 10 , iter = 20 , Nimp = 10 ,
 					"burnin" = burnin , "iter"=iter , "Nimp"=Nimp ,
 					"time" = Sys.time()
 					)
+	res$nobs <- nrow(data)
+	res$nvars <- ncol(data)					
 	class(res) <- "mids.1chain"
     return(res)
             }
@@ -118,14 +122,20 @@ mice.1chain <- function(data, burnin = 10 , iter = 20 , Nimp = 10 ,
 ###############################################################################
 # S3 method summary
 summary.mids.1chain <- function( object , ... ){
-   cat("*** Multiply imputed dataset using one chain\n")
-   cat("***" , paste0("Date : " , Sys.time() ) , "\n\n")
+   cat("Multiply imputed dataset using one chain\n\n")
+#   cat("***" , paste0("Date : " , Sys.time() ) , "\n\n")
    cat( paste0( "Number of iterations = " , object$iter) , "\n")
    cat( paste0( "Number of burnin-iterations = " , object$burnin) , "\n")   
-   cat( paste0( "Number of imputations = " , object$Nimp) , "\n\n")
+   cat( paste0( "Number of imputations = " , object$Nimp) , "\n")   
+   cat( paste0( object$nobs , " cases and " , object$nvars , " variables \n\n" ) )   
    cat("---------\n")   
    print( summary( object$midsobj ) )
 	}
+# print method	
+print.mids.1chain <- function( x , ...){
+	summary.mids.1chain( object = x , ...)
+	}	
+	
 ################################################################################
 # S3 plot method
 plot.mids.1chain <- function( x , plot.burnin=FALSE , ask=TRUE , ... ){
