@@ -9,7 +9,7 @@ mice.impute.grouped <- function (y, ry, x, low=NULL , upp=NULL ,  ...){
     Y <- cbind( low[[vname]] , upp[[vname]] )        
     # draw bootstrap sample
     N <- nrow(Y)
-    ind <- sample( 1:N , replace=TRUE )
+    ind <- base::sample( 1:N , replace=TRUE )
     X1 <- x[ ind , -1]
     Y1 <- Y[ ind , ]
     # fit grouped model to bootstrap sample
@@ -19,12 +19,12 @@ mice.impute.grouped <- function (y, ry, x, low=NULL , upp=NULL ,  ...){
 	# calculate predicted values
 	ypred <- x %*% beta
 	# compute quantiles
-	qlow <- pnorm( Y[,1] , mean=ypred , sd = sigma )
-	qupp <- pnorm( Y[,2] , mean=ypred , sd = sigma )
+	qlow <- stats::pnorm( Y[,1] , mean=ypred , sd = sigma )
+	qupp <- stats::pnorm( Y[,2] , mean=ypred , sd = sigma )
     # draw randomly a quantile
-	samp_quant <- qlow + ( qupp - qlow)*runif(N)
+	samp_quant <- qlow + ( qupp - qlow)* stats::runif(N)
 	# draw imputed value
-	yimp <- qnorm( samp_quant , mean=ypred , sd = sigma )
+	yimp <- stats::qnorm( samp_quant , mean=ypred , sd = sigma )
 # dfr <- cbind( ypred , Y , qlow , qupp , samp_quant , yimp)
 # Revalpr("round(dfr[1:30,],4)")	
     return(yimp)    
