@@ -1,7 +1,7 @@
 pca.covridge <- function( x , ridge = 10^(-10) ){
     cx <- cov(x)
     diag(cx) <- diag(cx) + ridge
-    pcax <- princomp( covmat=cx )
+    pcax <- stats::princomp( covmat=cx )
     L <- pcax$loadings
     sdev <- pcax$sdev
     D <- diag( pcax$sdev^2)
