@@ -2,7 +2,8 @@
 
 
 ################################################################
-pool.nmi.scalar.helper <- function( qhat , u , NV , NB , NW , comp_cov=TRUE){
+pool.nmi.scalar.helper <- function( qhat , u , NV , NB , NW , comp_cov=TRUE ,
+        method=1 ){
 
 		# Input: qhat, u, NV, NB, NW 
 		# qhat ... estimator
@@ -49,16 +50,45 @@ pool.nmi.scalar.helper <- function( qhat , u , NV , NB , NW , comp_cov=TRUE){
 					}  # end vv1			
 				}	# end comp_cov	
 				
-		
 		Um <- ubar
 		Tm <- (1+1/NB)*Bm + (1-1/NW)*Wm + Um
-		df <- ( (1+1/NB)*Bm )^2 / (NB-1 + eps) / Tm^2 +	( (1-1/NW)*Wm )^2 / NB / (NW-1 + eps) / Tm^2
+		df <- ( (1+1/NB)*Bm )^2 / (NB-1 + eps) / Tm^2 +	
+					( (1-1/NW)*Wm )^2 / NB / (NW-1 + eps) / Tm^2
 		df <- 1 / diag( df )
 		# fraction of missing information
-		lambda <- diag( ( Bm + (1-1/NW)*Wm ) / ( Um + Bm + (1-1/NW)*Wm ) )
-		lambda_Within <- diag( Wm / ( Um + Wm ) )
+		# in case of MI lambda is calculated as
+		#		lambda <- (1 + 1/m) * diag(b/t)
+		if (method == 1){
+			# lambda <- diag( ( Bm + (1-1/NW)*Wm ) / ( Um + Bm + (1-1/NW)*Wm ) )
+			rmn <- ( ( 1 + 0 ) * diag(Bm) + ( 1 - 1 /NW ) * diag(Wm) ) / diag(Um)	
+						}
+						
+						
+		#****
+		#@@@ Change ARb 2016-02-03
+		# Harel & Schafer formula Sect. 3		
+		if ( method == 2){
+			rmn <- ( ( 1 + 1/NB) * diag(Bm) + ( 1 - 1 /NW ) * diag(Wm) ) / diag(Um)			
+						}
+		lambda <- rmn / ( 1 + rmn )
+		
+		
+		#*** ARb 2016-02-01
+		# check correct formula for lambda because it differs
+		# in case of MI data. 
+		#@@@ Change ARb 2016-02-03
+		if (method == 1){
+			 # lambda_Within <- diag( Wm / ( Um + Wm ) )
+			rBA <- ( 1 + 0 ) * diag(Wm) / diag(Um)			 
+						}
+		if (method == 2){
+			rBA <- ( 1 + 1 / (NB*NW) ) * diag(Wm) / diag(Um)			 
+						}		    
+		lambda_Within <- rBA / ( 1 + rBA )						
 		lambda_Between <- lambda - lambda_Within
-			
+		#*** In the MI case 
+		# fmi <- (r + 2/(df + 3))/(r + 1)	
+		
 		#*******
 		# output
 		fit <- list( "qhat" = qhat , "u"=u , 		
@@ -68,4 +98,5 @@ pool.nmi.scalar.helper <- function( qhat , u , NV , NB , NW , comp_cov=TRUE){
 						lambda_Within=lambda_Within , 
 						"NV" = NV )						
 		return(fit)
-		}
\ No newline at end of file
+		}
+###########################################
