@@ -1,9 +1,11 @@
+##################################################
+# write mice imputation object
 write.mice.imputation <- function( mi.res , name , include.varnames = TRUE , long = TRUE , 
                            mids2spss = TRUE , spss.dec = "," , dattype = NULL ){
 
 		
 		ismids <- TRUE
-		if ( class(mi.res) == "mids.1chain" ){
+		if ( inherits(mi.res ,"mids.1chain" ) ) {
                 mi.res0 <- mi.res		
 				mi.res <- mi.res$midsobj 
 				mi.res$chainMean <- mi.res0$chainMean
@@ -11,13 +13,18 @@ write.mice.imputation <- function( mi.res , name , include.varnames = TRUE , lon
 				ismids <- FALSE
 						}
 		
-        pf.subf <- file.path( getwd() , paste("IMP_" , name , sep=""))
-        dir.create(pf.subf)                 # lege Unterordner an
-        # schreibe Variablenlegende heraus
-        base::writeLines( colnames(mi.res$data) , file.path( pf.subf , paste( name , "__LEGENDE.txt" , sep="") ))
+        # pf.subf <- file.path( getwd() , paste("IMP_" , name , sep=""))
+		pf.subf <- file.path( getwd() , paste( name , sep=""))
+		
+        dir.create(pf.subf)                 # define subdirectory
+        # write legend of variables
+        base::writeLines( colnames(mi.res$data) , 
+		      file.path( pf.subf , paste( name , "__LEGEND.txt" , sep="") ))
         l1 <- paste( name , "__IMPDATA" , 1:mi.res$m , ".dat" , sep="")
-        utils::write.table( l1 , file.path( pf.subf , paste( name , "__IMP_LIST.txt" , sep="") ) , col.names=F , row.names=F , quote=F)
-        # lege Summary der Imputation in dieser Unterordner ab
+        utils::write.table( l1 , file.path( pf.subf , 
+		                  paste( name , "__IMP_LIST.txt" , sep="") ) , 
+				       col.names=F , row.names=F , quote=F)
+        # save summary in subdirectory
         sink( file.path( pf.subf , paste( name , "__IMP_SUMMARY.txt" , sep="") ) , split=TRUE )
         cat( paste(Sys.time()) , "\n\n" , pf.subf , "\n\n" )
             print( summary( mi.res ) ) 
@@ -48,24 +55,28 @@ write.mice.imputation <- function( mi.res , name , include.varnames = TRUE , lon
                         cat("\n",i); flush.console() 
                                 }
         cat("\n")
-        # schreibe langen Datensatz heraus
+        # write data file in long format
         utils::write.table( mice::complete( mi.res , action = "long" ) , 
                                     file = file.path( pf.subf , paste( name , "__LONG.dat" , sep="")) , quote=F , 
                                         row.names=F , col.names= TRUE , na ="." )         
-        # Variablennamen
+        # variable names
         base::writeLines( colnames( mice::complete( mi.res , 1 ) ) , file.path( pf.subf , paste( name , "__VARNAMES.txt" , sep="")) )
-        # SPSS-Datensatz herausschreiben
+        # write SPSS file
         if (mids2spss){ 
             mice::mids2spss(mi.res, filedat = paste( name , "__SPSS.txt" , sep="") , 
-                            filesps = paste( name , "__SPSS.sps", sep="") , 
-                                path = pf.subf , dec = spss.dec )
+                               filesps = paste( name , "__SPSS.sps", sep="") , 
+                               path = pf.subf , dec = spss.dec )
                                 }
         # Mplus-Body                
-        if ( include.varnames == FALSE){
+        if ( ! include.varnames ){
+		
+			vars <- colnames(mi.res$data) 		
+			vars2 <- VariableNames2String( vars , breaks=60)
+		
             l1 <- c("TITLE: xxxx ;" , "" , "DATA: " , "" ,
                     paste( "FILE IS " , name , "__IMP_LIST.txt;" , sep=""),  "TYPE = IMPUTATION;"  , "" , 
                         "VARIABLE:" , "" , "NAMES ARE" , 
-                        colnames(mi.res$data) , ";" , "" , "! edit usevariables are;" , "!usevar are" , 
+                       vars2 , ";" , "" , "! edit usevariables are;" , "!usevar are" , 
                         "   " , "" , "MISSING = ." , "" , "!........................." ,
                         "! Mplus statements"
                             )
@@ -80,3 +91,4 @@ write.mice.imputation <- function( mi.res , name , include.varnames = TRUE , lon
 		datlist <- mids2datlist( mi.res )
 		base::save( datlist , file=file.path( pf.subf , paste( name , "__DATALIST.Rdata" , sep="") ) )		
         }
+#########################################################################
\ No newline at end of file
